OLS Client |release| Documentation
==================================
Installation
------------
The most recent release can be installed from
`PyPI <https://pypi.org/project/ols_client>`_ with:

.. code-block:: shell

    $ pip install ols_client

The most recent code and data can be installed directly from GitHub with:

.. code-block:: shell

    $ pip install git+https://github.com/cthoyt/ols-client.git

To install in development mode, use the following:

.. code-block:: shell

    $ git clone git+https://github.com/cthoyt/ols-client.git
    $ cd ols-client
    $ pip install -e .


Table of Contents
-----------------
.. toctree::
   :maxdepth: 2
   :caption: Getting Started
   :name: start

   usage
   cli

Indices and Tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
